from setuptools import setup
print("lemme install that real quick")
setup(
    name="WOAHLIB",
    description="Woah!",
    url="https://pypi.org/project/WOAHLIB/1.1.1/",
    version="1.1.1",
    author="Woah",
    author_email="davidbeumers@gmail.com",
    license="MIT",
    packages=["woahlib"],
    zip_safe = False
)
print("yoo letsgo installed!!")